@@ -38,12 +38,13 @@ class GmailClient(EmailClient):
     def extract_from_html(self, string):
         try:
             parsed = BeautifulSoup(string)
-            if parsed.div.div.div is None:
-                body = ''.join(str(tag).strip() for tag in parsed.div.div.contents[19:])
-                sender = parsed.div.div.span.a.get_text()
+            gmail_quote = parsed.div.find("div", class_ = "gmail_quote")
+            if gmail_quote.div is None:
+                body = ''.join(str(tag).strip() for tag in gmail_quote.contents[19:])
+                sender = gmail_quote.span.a.get_text()
             else:
-                body = ''.join(str(tag).strip() for tag in parsed.div.div.div.contents)
-                sender = parsed.div.div.span.a.get_text()
+                body = ''.join(str(tag).strip() for tag in gmail_quote.div.contents)
+                sender = gmail_quote.span.a.get_text()
             return {"body" : body, "sender" : sender}
         except Exception as e:
             raise ExtractionError("Given email did not parse successfully: " + str(e))
