@@ -17,9 +17,9 @@
 
 
 
-from gmail_test import TestGMailUnforward
-from outlook_test import TestOutlookUnforward
-from extractor_test import ExtractorTest
+from unforward.test.gmail_test import TestGMailUnforward
+from unforward.test.outlook_test import TestOutlookUnforward
+from unforward.test.extractor_test import ExtractorTest
 
 __all__ = ['TestGMailUnforward', 'TestOutlookUnforward', 'ExtractorTest']
 
