@@ -28,6 +28,12 @@ examples =  [
                     "result" : {'sender' : 'jamie@moonrider.com',
                                 'body'   : '<p> Original Email</p>'}
                 },
+                {
+                    "client": ["gmail"],
+                    "file" : "examples/gmail_forward_3.html",
+                    "result" : {'sender' : 'builds@drone.io',
+                                'body'   : '<p>Build Failed</p>'}
+                },
                 {
                     "client": ["blackberry"],
                     "file" : "examples/blackberry_forward.html",
